#!/usr/bin/python3

import argparse
import json
import logging
import pathlib
import re

import requests

PKG_SOURCE_VERSION = re.compile(r'PKG_SOURCE_VERSION:=(\S+)')


def get_package_version(makefile_url: str) -> str:
    resp = requests.get(makefile_url)
    version = PKG_SOURCE_VERSION.search(resp.text).group(1)
    return version


if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO)

    config_path = pathlib.Path(__file__).absolute().parent / 'bump_code_analysis_lib_versions.json'

    with config_path.open('r') as f:
        config = json.load(f)
        logging.info(f'Configuration: {config}')

    parser = argparse.ArgumentParser()
    parser.add_argument(
        'dockerfile',
        help='Dockerfile to update version arguments in',
        metavar='DOCKERFILE',
        type=argparse.FileType('r'),
    )
    args = parser.parse_args()

    with args.dockerfile as f:
        dockerfile = f.read()

    dockerfile_orig = dockerfile

    for package_name, makefile_url in config.items():
        logging.info(f'Fetching Makefile for package {package_name}')
        package_version = get_package_version(makefile_url)
        logging.info(f'Package {package_name} has version {package_version} in Makefile')

        docker_arg = f'{package_name.upper()}_VERSION'
        dockerfile = re.sub(fr'(?<=ARG {docker_arg}=)\S+', package_version, dockerfile)

    if dockerfile != dockerfile_orig:
        logging.info('Dockerfile changed, writing to disk')
        with open(args.dockerfile.name, 'w') as f:
            f.write(dockerfile)
